@@ -20,12 +20,13 @@
 # 
 # 
 
-import os, sys, string, gettext
+import os, sys, string
 
-_ = gettext.gettext
+import locale
+charset = locale.getlocale () [1] or 'ascii'
 
 if len (sys.argv) < 4 or len (sys.argv) > 5:
-    print _("usage: pybconvert <source>..<target> <input> [output]")
+    print _("usage: pybconvert <source>..<target> <input> [output]").encode (charset)
     sys.exit (1)
 
 
@@ -34,7 +35,7 @@ format = sys.argv [2]
 try:
     source, target = string.split (format, '..')
 except:
-    print _("pybconvert: bad conversion format")
+    print _("pybconvert: error: bad conversion format").encode (charset)
     sys.exit (1)
 
 
